@@ -5,11 +5,6 @@ use test_case::test_case;
 
 use crypto_crawler::*;
 use crypto_markets::MarketType;
-use std::thread_local;
-use std::{
-    cell::RefCell,
-    sync::{Arc, Mutex},
-};
 
 const EXCHANGE_NAME: &str = "deribit";
 
@@ -17,7 +12,7 @@ const EXCHANGE_NAME: &str = "deribit";
 #[test_case(MarketType::InverseFuture, "BTC-31DEC21")]
 #[test_case(MarketType::EuropeanOption, "BTC-31DEC21-400000-C"; "inconclusive")]
 fn test_crawl_trade(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
         market_type,
@@ -30,30 +25,14 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseFuture)]
 #[test_case(MarketType::EuropeanOption)]
 fn test_crawl_trade_all(market_type: MarketType) {
-    thread_local! {
-        static MESSAGES: RefCell<Vec<Message>> = RefCell::new(Vec::new());
-    }
-
-    let on_msg = Arc::new(Mutex::new(|msg: Message| {
-        MESSAGES.with(|messages| messages.borrow_mut().push(msg))
-    }));
-    crawl_trade(EXCHANGE_NAME, market_type, None, on_msg, Some(0));
-
-    MESSAGES.with(|slf| {
-        let messages = slf.borrow();
-
-        assert!(!messages.is_empty());
-        assert_eq!(messages[0].exchange, EXCHANGE_NAME.to_string());
-        assert_eq!(messages[0].market_type, market_type);
-        assert_eq!(messages[0].msg_type, MessageType::Trade);
-    });
+    test_all_symbols!(crawl_trade, EXCHANGE_NAME, market_type, MessageType::Trade)
 }
 
 #[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
 #[test_case(MarketType::InverseFuture, "BTC-31DEC21")]
 #[test_case(MarketType::EuropeanOption, "BTC-31DEC21-400000-C")]
 fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
         market_type,
@@ -66,7 +45,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseFuture, "BTC-31DEC21")]
 #[test_case(MarketType::EuropeanOption, "BTC-31DEC21-400000-C")]
 fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_bbo,
         EXCHANGE_NAME,
         market_type,
@@ -79,7 +58,7 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseFuture, "BTC-31DEC21")]
 #[test_case(MarketType::EuropeanOption, "BTC-31DEC21-400000-C")]
 fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_l2_topk,
         EXCHANGE_NAME,
         market_type,
@@ -92,7 +71,7 @@ fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseFuture, "BTC-31DEC21")]
 #[test_case(MarketType::EuropeanOption, "BTC-31DEC21-400000-C")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    gen_test_snapshot_code!(
+    test_one_symbol!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -105,7 +84,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseFuture)]
 #[test_case(MarketType::EuropeanOption; "inconclusive")]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    gen_test_snapshot_without_symbol_code!(
+    test_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -117,7 +96,7 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 #[test_case(MarketType::InverseFuture, "BTC-31DEC21")]
 #[test_case(MarketType::EuropeanOption, "BTC-31DEC21-400000-C")]
 fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
         market_type,
