@@ -5,11 +5,6 @@ use test_case::test_case;
 
 use crypto_crawler::*;
 use crypto_markets::MarketType;
-use std::thread_local;
-use std::{
-    cell::RefCell,
-    sync::{Arc, Mutex},
-};
 
 const EXCHANGE_NAME: &str = "kucoin";
 
@@ -18,7 +13,7 @@ const EXCHANGE_NAME: &str = "kucoin";
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
 #[test_case(MarketType::InverseFuture, "XBTMZ21"; "inconclusive")]
 fn test_crawl_trade(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
         market_type,
@@ -32,7 +27,7 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
 #[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
         market_type,
@@ -46,7 +41,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
 #[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_bbo,
         EXCHANGE_NAME,
         market_type,
@@ -60,7 +55,7 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
 #[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_l2_topk,
         EXCHANGE_NAME,
         market_type,
@@ -74,7 +69,7 @@ fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
 #[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_l3_event,
         EXCHANGE_NAME,
         market_type,
@@ -88,7 +83,7 @@ fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
 #[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    gen_test_snapshot_code!(
+    test_one_symbol!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -102,7 +97,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap)]
 #[test_case(MarketType::InverseFuture)]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    gen_test_snapshot_without_symbol_code!(
+    test_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -115,7 +110,7 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
 #[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
-    gen_test_snapshot_code!(
+    test_one_symbol!(
         crawl_l3_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -129,7 +124,7 @@ fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
 #[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
         market_type,
